@@ -3,6 +3,8 @@ use Catmandu::Sane;
 use Moo;
 extends qw(Catmandu::AlephX::Metadata);
 
+#parse marcxml into Catmandu marc array
+
 sub parse {
   my($class,$xpath)=@_;
 
@@ -10,6 +12,7 @@ sub parse {
 
   my $leader = $xpath->findvalue("./*[local-name() = 'leader']");
   my $fmt = "";
+  my $_id;
 
   for my $controlfield($xpath->find("./*[local-name() = 'controlfield']")->get_nodelist()){
     my $tag = $controlfield->findvalue('@tag');
@@ -18,6 +21,9 @@ sub parse {
       $fmt = $value;
       next;
     }
+    if($tag eq "001"){
+      $_id = $value;
+    }
     #leader can also be specified in a controlfield??
     elsif($tag eq "LDR"){
       $leader = $value; 
@@ -46,7 +52,7 @@ sub parse {
 
   }
 
-  __PACKAGE__->new(type => 'oai_marc',data => \@marc); 
+  __PACKAGE__->new(type => 'oai_marc',data => { record => \@marc, _id => $_id }); 
 }
 
 1;
