@@ -1,6 +1,6 @@
 package Catmandu::AlephX::Op::IllBorInfo;
 use Catmandu::Sane;
-use Data::Util qw(:check :validate);
+use Catmandu::Util qw(:check);
 use Moo;
 
 extends('Catmandu::AlephX::Op::BorAuth');
@@ -10,7 +10,7 @@ has z308 => (
   is => 'ro',
   lazy => 1,
   isa => sub {
-    array_ref($_[0]);
+    check_array_ref($_[0]);
   },
   default => sub {
     [];
@@ -22,20 +22,22 @@ sub op { 'ill-bor-info' }
 sub parse {
   my($class,$str_ref) = @_;
   my $xpath = xpath($str_ref);
+  my $op = op();
 
   my @keys = qw(z303 z304 z305 z308);
   my %args = ();
 
   for my $key(@keys){
-    my($l) = $xpath->find("/ill-bor-info/$key")->get_nodelist();
+    my($l) = $xpath->find("/$op/$key")->get_nodelist();
     my $data = $l ? get_children($l,1) : {};
     $args{$key} = $data;
   }
 
   __PACKAGE__->new(
     %args,
-    session_id => $xpath->findvalue('/ill-bor-info/session-id'),
-    error => $xpath->findvalue('/ill-bor-info/error')
+    session_id => $xpath->findvalue("/$op/session-id"),
+    errors => $class->parse_errors($xpath),
+    content_ref => $str_ref
   );
   
 }
