@@ -1,6 +1,6 @@
 package Catmandu::AlephX::Op::ItemData;
 use Catmandu::Sane;
-use Data::Util qw(:check :validate);
+use Catmandu::Util qw(:check :is);
 use Moo;
 
 with('Catmandu::AlephX::Response');
@@ -9,9 +9,9 @@ has items => (
   is => 'ro',
   lazy => 1,
   isa => sub{
-    array_ref($_[0]);
+    check_array_ref($_[0]);
     for(@{ $_[0] }){
-      hash_ref($_);
+      check_hash_ref($_);
     }
   },
   default => sub {
@@ -23,16 +23,19 @@ sub op { 'item-data' }
 sub parse {
   my($class,$str_ref) = @_;
   my $xpath = xpath($str_ref);
+  my $op = op();
 
   my @items;
 
-  for my $item($xpath->find('/item-data/item')->get_nodelist()){
+  for my $item($xpath->find("/$op/item")->get_nodelist()){
     push @items,get_children($item,1);
   }
+
   __PACKAGE__->new(
-    session_id => $xpath->findvalue('/item-data/session-id'),
-    error => $xpath->findvalue('/item-data/error'),
-    items => \@items
+    session_id => $xpath->findvalue("/$op/session-id"),
+    errors => $class->parse_errors($xpath),
+    items => \@items,
+    content_ref => $str_ref
   );
 } 
 
